package com.aitrainer.api.test

import com.aitrainer.api.controller.ExercisePlanController
import com.aitrainer.api.model.ExercisePlan
import com.aitrainer.api.repository.ExercisePlanRepository
import org.junit.jupiter.api.Test
import org.junit.jupiter.api.TestInstance
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.RequestHeader
import java.util.*
import kotlin.test.assertEquals

@SpringBootTest
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
class ExercisePlanTest {

    @Autowired
    private lateinit var exercisePlanRepository: ExercisePlanRepository


    @Test
    fun testInsert() {
        val exercisePlan = ExercisePlan (
            name = "Bossanyi private",
            description = "",
            customerId = 90,
            private = true,
            dateAdd = "2020-09-05 17:00"
        )


        val savedPlan: ExercisePlan = exercisePlanRepository.save(exercisePlan)
        assertEquals(savedPlan.customerId, 90)
        exercisePlanRepository.delete(savedPlan);

    }

    @Test
    fun testGetLastPlan() {
        val exercisePlan: ExercisePlan? = exercisePlanRepository.getLastExercisePlan(90)
        assertEquals(exercisePlan?.name, "Boss private")
        assertEquals(exercisePlan?.dateAdd, "2020-09-06 08:00:00")

        val exercisePlan2: ExercisePlan? = exercisePlanRepository.getLastExercisePlan(91)
        assertEquals(exercisePlan2, null)
    }

    @Test
    fun testUpdatePlan() {
        val plan: ExercisePlan = exercisePlanRepository.findById(6).orElse(null)
        assertEquals(plan.name, "Boss private")
        assertEquals(plan.customerId, 90)
        plan.dateUpd = Date().toString()
        plan.description = "Bossanyi updated"

        val planController = ExercisePlanController(exercisePlanRepository)
        val response: ResponseEntity<*> = planController.updateExercisePlanById(6, plan, null)
        val updatedPlan = response.body as ExercisePlan
        assertEquals(plan.name, "Boss private")
        assertEquals(plan.customerId, 90)
        assertEquals(plan.description, "Bossanyi updated")
        assertEquals(plan.exercisePlanId, 6)

        updatedPlan.description = ""
        planController.updateExercisePlanById(6, updatedPlan, null)
    }
}